@@ -35,7 +35,10 @@ class DataChunkImage(DataChunkData):
     def encode_as_base64(self):
         if isinstance(self.value, np.ndarray):
             _, frame_arr = cv2.imencode('.png', self.value)
-            self.value = base64.b64encode(frame_arr).decode('utf-8')
+            self.value = base64.b64encode(frame_arr).decode("utf-8")
 
     def base64_decoder(self, frame: str):
-        return cv2.imdecode(np.fromstring(frame, dtype=np.uint8), cv2.IMREAD_UNCHANGED)
+        image_data = base64.b64decode(frame)
+        image_array = np.frombuffer(image_data, dtype=np.uint8)
+        np_array = cv2.imdecode(image_array, cv2.IMREAD_UNCHANGED)
+        return np_array
